(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     24911,        571]
NotebookOptionsPosition[     23730,        527]
NotebookOutlinePosition[     24109,        544]
CellTagsIndexPosition[     24066,        541]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "Numerical solution of harmonic oscillator ",
 Cell[BoxData[
  FormBox[
   RowBox[{"V", "=", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["bx", "2"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " w/ b=1 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"mKelvin", "/", 
    SuperscriptBox["cm", "2"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", Li-6 atom"
}], "Subsubsection",
 CellChangeTimes->{{3.5263770847276697`*^9, 3.526377090723091*^9}, {
   3.526377396968935*^9, 3.526377447509384*^9}, {3.5263853328615932`*^9, 
   3.526385349527494*^9}, 3.526385854924625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mcsq", "=", 
   RowBox[{"6", " ", "931.5", " ", 
    SuperscriptBox["10", "6"], " ", "eV", " ", "11600", " ", 
    FractionBox["kelvin", "eV"]}]}], ";", 
  RowBox[{"hbarc", "=", 
   RowBox[{"1973", " ", "eV", " ", "11600", " ", 
    RowBox[{"kelvin", "/", "eV"}], " ", "Angstrom"}]}], ";", 
  RowBox[{"b", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]], " ", 
      RowBox[{"kelvin", "/", 
       SuperscriptBox["cm", "2"]}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["10", "8"], " ", 
        RowBox[{"Angstrom", "/", "cm"}]}], ")"}], "2"]], "//", 
    "N"}]}]}]], "Input",
 CellChangeTimes->{{3.526377451258273*^9, 3.526377513871673*^9}, 
   3.526385854926156*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"1.`*^-19", " ", "kelvin"}], 
  SuperscriptBox["Angstrom", "2"]]], "Output",
 CellChangeTimes->{3.526385986004938*^9}]
}, Open  ]],

Cell["unit of length", "Text",
 CellChangeTimes->{{3.526386587108492*^9, 3.5263865888602962`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      SuperscriptBox["hbarc", "2"], 
      RowBox[{"mcsq", " ", "b"}]], ")"}], 
    RowBox[{"1", "/", "4"}]], "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.526377519680037*^9, 3.526377565683524*^9}, 
   3.526385854930987*^9}],

Cell[BoxData[
 RowBox[{"94807.8968328216`", " ", "Angstrom"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.5263775591190557`*^9, 3.52637756638375*^9}, {
   3.526385854932392*^9, 3.526385866939907*^9}, 3.526385990315795*^9}]
}, Open  ]],

Cell["unit of energy", "Text",
 CellChangeTimes->{{3.52638659405206*^9, 3.526386595764001*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eunit", "=", 
  FractionBox[
   SuperscriptBox["hbarc", "2"], 
   RowBox[{"mcsq", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Input",
 CellChangeTimes->{{3.526386601014328*^9, 3.5263866449886293`*^9}}],

Cell[BoxData[
 RowBox[{"8.988537301862944`*^-10", " ", "kelvin"}]], "Output",
 CellChangeTimes->{3.5263866484691763`*^9}]
}, Open  ]],

Cell["solve Schrodinger eqn, ", "Text",
 CellChangeTimes->{{3.5263856605047493`*^9, 3.526385679639504*^9}, 
   3.526385854933651*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SE", "[", "\[Epsilon]_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"-", "1"}], "2"], 
     RowBox[{
      RowBox[{"psi", "''"}], "[", "y", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["y", "2"], 
     RowBox[{"psi", "[", "y", "]"}]}]}], "\[Equal]", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"psi", "[", "y", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.526385683863966*^9, 3.52638570112245*^9}, {
  3.526385840751382*^9, 3.526385854934306*^9}}],

Cell["\<\
boundary condition deep into forbidden region\
\>", "Text",
 CellChangeTimes->{{3.52638571182444*^9, 3.526385726301467*^9}, {
   3.526385761196393*^9, 3.5263857817154703`*^9}, 3.5263858549417553`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BC", "[", "y0_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"psi", "[", "y0", "]"}], "\[Equal]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"psi", "'"}], "[", "y0", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", "y0"}], " ", 
      RowBox[{"psi", "[", "y0", "]"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.5263857850407124`*^9, 3.526385814255219*^9}, 
   3.526385854942178*^9, 3.5263867817383823`*^9}],

Cell["\<\
Numerically integrate SE from y0 in to 0, calculate values at y=0
Try different values of \[Epsilon] to either get psi\[CloseCurlyQuote][0]=0 \
or psi[0]=0, depending on whether you are after symmetric or antisymmetric \
solution
Note:  If the potential was not symmetric, then you would also need to \
integrate from -y0 to 0 and the condition for a proper eigenfunction would be \
that the wavefunction and its derivative would be continuous at y=0.\
\>", "Text",
 CellChangeTimes->{{3.526386054929287*^9, 3.526386109174787*^9}, {
  3.5263861934763727`*^9, 3.526386365605213*^9}, {3.526386524815424*^9, 
  3.52638652707121*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Epsilon]", "=", "0.5000094043887147`"}], ",", 
     RowBox[{"y0", "=", "20"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Numerical", " ", "Integration", " ", "of", " ", "SE", " ", "from", " ", 
     "y0", " ", "to", " ", "0"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SE", "[", "\[Epsilon]", "]"}], ",", 
         RowBox[{"BC", "[", "y0", "]"}]}], "}"}], ",", "psi", ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "y0", ",", "0"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "print", " ", "wavefunction", " ", "and", " ", "derivative", " ", "at", 
      " ", "0"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Print", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"psi", "'"}], "[", "0", "]"}], 
         RowBox[{"psi", "[", "0", "]"}]], ",", 
        FractionBox[
         RowBox[{"psi", "[", "0", "]"}], 
         RowBox[{
          RowBox[{"psi", "'"}], "[", "0", "]"}]]}], "}"}], "/.", "sol"}], 
     "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"plot", " ", "result"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"psi", "[", "y", "]"}], "/.", "sol"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "0", ",", "7"}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.526385285081607*^9, 3.5263853135834703`*^9}, {
   3.5263853598134737`*^9, 3.526385376252166*^9}, {3.5263854279467688`*^9, 
   3.526385457065254*^9}, {3.5263854940720587`*^9, 3.526385519375231*^9}, {
   3.5263855635345716`*^9, 3.526385633850932*^9}, 3.52638585494433*^9, {
   3.526386020405788*^9, 3.526386047347632*^9}, {3.5263861179975977`*^9, 
   3.5263861681962233`*^9}, {3.5263906178996887`*^9, 3.526390770454134*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"0.000016653715500122788`", ",", "60046.660457999715`"}], "}"}], 
  "}"}]], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.52638617543052*^9, 3.526386385933682*^9, 3.526386786427775*^9, {
   3.5263906194359694`*^9, 3.526390783552084*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnk0lV8Xx83z7HKvS+ZZhkSi8uwKIbnnICqplCFTIVGGkiihyJxKQlIy
RiRlyky/igyROaKBFFfG1/vPc9Zn7XP23t/vXuucR+bkWStnJgYGhoKNz//X
h4fyyiM3XzVsYfmar0rQcfaSaFhWsiPxxG58u9IGH4hmVQlJ9iH6JYk3Ehts
emc9LtcxkGDtWtvFvcGZncErbslXiI/WWyvmDOk44/PFovXlCOLrwNzmzg2+
P+LvlOQYRQzyHbn3bIPTvp2jqDXdIiymotkub3B7wHaXE8m3ieLWYg/zDd6/
vA3UWhKIC2eX2/g2uPWSLnVhOYn4O5uu1L5roz6Tzt8ajVTi0NveS2Eb3BSh
/S7aMY0of/n9w5YNNuHckmubeI9YXpKW+byTjt/GaIbJNKUT41zNnkEbPGIm
etc++SFRYNeylLtjo99oEY7awkyC98DoLt0NPtFBOq/YkkWwhk5fqjSg40Ek
TPu9/IjgKIpeKdSn4/R4oSpbkceEJouogfQGO3QJqlRp5BJaB30Dbmyn4wE7
Aebrjk+J2pKWPyZ6dHzvDr/3j8A84vLkt613t9GxfT/fF5z4jAh0lfX/pkvH
n4/xlks0FRBlv3yYz+jQ8Q/tCN3DycXEfft6G4UtG/50svzglishYrlbKnZr
0fEzv/DMN4UlRA5nrrydJh17vLjKL9/ynDjEYEb2Uqfjaf2wqV/LZcQD095Q
Y5UN/z4zZjyMfEG8/7Brp6oyHT8JumJrI1JO0OXesXEo0fHp16H1LzUqCLr/
rY4CeTqehMv3wx0riQCxRuKJFB03jqxZ6/2qJJ7euhVvK0nHOWGXuKYDXxGP
3E+urkjQscvbkABaYhXhUCQkrUul4/F9wZja9Iawbt/x2opExz6Pq5gOJdcS
URX8kUbsdGwkeVnv3mgt8Tzo26wDKx1TknZ7DmvUERf3HLQ9y0zHNWGNn043
1RHD3tJSgesLmO/Y+9yLi/VEPnfTmCZ9AT8jjVvePdJIrHZ80JD8uoBDo3Ou
DuU0EkJ9x09XjC5gaya3Crk/jYRxAqXefHgBL838lHkW3UT0dllO2PUvYLM2
+t+qqmai1NBPnfRhAU9c4b47KNlGuFVsUiS/WsCVix3/yXq0EUdes5brVCzg
W2fjWFzL24jJ/rYk87IFrOsgcmaG1k58ydtqdrxwAYdvl9rNcKWDMLL7Obg5
awHLzGhPyoz9R9SUa961v7GANTTy75RYfyTyGphvSqEF7AtcLQcCPhJRnnXO
tywW8Asr18VvaR+J+oFH0wumC9gwQMZOavQjcY3Uy1q2ewFb1iSRYrw7iezD
a1++ai9gL6tLsc43u4jEeGDfRNrww58WQWnqJry2FX7+92Eez0Y+K30+3U04
xpaOZ3fMY527nOOWfD2EQcdtHvOWeVxVXb8n4mAPMfTSuiGsZh63c2xnmBvr
IdLiAkwLCubxjzTpoDaGPuKxn6XA7xvzWK36t/clg37CV0DTdc/OeewSHPPR
xaGfWO5WtrfSm8eZ+ko6tNB+gk2kVNFBex5TSo/SpRr7CSEm6YOnlOcx25Om
kFo8QGQ1XQrXJs3j4fj7USxuX4iZ+XOjQ9N/cbKLWXZUyhAx1nhsPjHxL2a8
/t5j/9IIUaE6d9L58x/8JNFKj/XFBCHRFaJqKDSHk0NomSPS3wn0lsm/wmAW
V7f7P/KYniFOphjG6pv8wB6vVRY7LOcI/amD0gPK3zAl7KAX/fJfwvUJbUjU
fxyPXUwuCBheIPp6dRaKKocxGkokblD+EbzkrBZ/9X689a/XXy/jZWKT4BXG
5NpP2CbfZ3TQcplg0s959CrvE/ZzOf+edmiZUNm6UjGT9AmX9gY/2+KxTGxP
K9K86v4J67yOdpqPWyaq6rk87EgbfO1JV/DAMkHGjgfL3LuwDuVrafS5FeL+
ml2NsWwn1t159PyTh6tEofm+naFV7zHP9/TcC09XiZX3Atnn897j0Tsj/fue
rxKPRM85BKS9x3F0lz0Tb1cJVsrQqwcX3uPpEh9+uW+rxOk5v69Xdd/jdJXr
T+5prBHalq6hmqf+w+zkki+xr9aIK8bqTGXOHbjvN7uJ/6d14vvPd0w6JS04
eD6wi2lonWg+GXzyTUILlv7382Tst3Wi67+PbafOt2AXhq7LucvrhEO//e31
7S34Ivv7oz8FGCC+9srri7XNmFX0XrKUHgNUkwqFz/Y04U1bdbjCrzIAzXLY
j4/ciH+VemHzSAaocpq6Mr7cgGu2PU4VuMkA236qqHUNN2AnA6rS/WQGIFLJ
Mgx5DfjpbgajF08YoDL6HHEDGvA21B7y7T8GEFR7YnLQ+y229HL6bSHBCGQ9
vv2Bo3X4UvbXwRVpRvAl5d3rb63Dhf0u7c8UGCGyo5TX5nkdFjB3e8yjyQgl
AoXUqPA6/FHxjEP7bkYwuLvsz6lchw8OB7Tsd2UEWx2jHrNztfiodfRD8xJG
GLgs8cGPWoNjonhil14wQorzuWcZrDX4de3N4KevGOH30ZPr9SPVWFIrzo6r
gRHeEUyFZrHVeJgnibe1hxHKjd/ct/7xBp9qTL9otsoIwyX3GswKXmN3/RJs
asoELlkr+mvoFfb//tHxsQUThO0+JPVH4xUOu//Hhw0zgY+S4zEu3lf4DqNu
/NvDTHCDYejWg5ZK3NxS/hE8mGDYutXwpFElVjjy2lr/FhO0XdZa04GXeDiw
+aBqFxPca2ga8Ebl+MfmKecbvUxgpz5ED9cux4uDnP7fBphAmh6UVEEqx/x7
9yfnfGWCS0eOrYb0vcCG3O+6ZelMIKVeznzZ6QW+d7fTTpzKDO3/zPlNQsuw
XdXgYZ4TzFCZdrTc7N1z3JyaQm51YoYrbJrkn8XPscF59Om6GzNckNDbWpL0
HEtq1CHmc8zQq3RP/aHDczzx4NG+pQhmICYmefhnSrD/VU/db3nM4D29JUGQ
UoKTzZcE3tKZgaVzWvTHlSLMofT83ZUVZljwNZGIcyvCgcyeMQQjCxxjiT5k
hYvwsaov7K+4WIDpIbBvkSnCihq1a8WbWODkJbZzueGFuEww8seDvSxgpmc7
vpVUgLt6RZqDYllAqn85q8UhD8toncn9lsACLwX2GP7blofPXG+MPJjKAmFi
5+7bCeRhzm0BZpoPWcAl0WX9Qf1TbJjQ2zpawgJzW80fH9n8FOceuNth1s0C
JZ9rfazYnuCgOulO8iZWkNSv1FHqz8HNYhefh8uwwrQATHx5mYNFfT4k/FZg
hePC+UpvUnNwkVSYTZsGKyR09Fcs2ebg8eCxT5eAFfbuCys8/ukRttTL6f16
ihXokx7cL/qysewztcHnT1lh2FXm85X1TNytLuF5uZAVOA6t69YMZ+IbhTxL
5qWscOO48wOVukw8W/JTZPQ1KxRsutofHJGJ37wsPCDwgRV+yDA0SPFl4sNN
W1970lnhXJeogobSQxw3uuOeghEbNHuzj1r/SsdGTptVf5uyQVfhE5ehynRM
/ypRUXWADSKsbWLKrqfjY1OrndZ2bFAflnQUZNPx5tlq7jB3NtDwYIppPHIf
N6/uDRqMY4Om6l99Zn138TrF4kjKFzY4d0jCf4jzDhZC4bcsRtnglY335pGh
VCx/vaqOcZIN2Hkaa6VfpGLT+c1qnrNs8PJDqsOhU6k4/gPvCjCzw+YFJ52H
NSlYIeq/+9PK7HDs5MTaoWvJG/+PViO7/NghUy2j0X1nIj6mHS3y5wI7KE7t
eH5XLBF7u9Wb5YawQ1rntmRGegJO7NlaInSdHcquHtP2KEnAg89JVyfvsMMf
BQ//ArUE7OPZLX+7mh1srrXefKUUj1O+HD49zsUBcoPJ3ppGcTg8dku1KT8H
3GHkvuepEod9d3OK5gtzgMdNe/p7vjhs+aii/rwEByyaGdElSmMxixdZil2D
Awz+MfwqGL+FfVe6PqlgDkBXqw7PWN/EFuJo79kUDjjTx3jJ/nQUNuhQSuu8
ywGFglvO/9gRhZUur8/qZXDA8X/GB2v4ozDTWEE6wxMOaGP4F6BZcQO/fMq7
dLuSA2wfrs3K8NzAigZtRaVfOEA6Tl+Ir+Y6ZjhsIrkkxwka2be1mg5GYBvd
F7KvlTmBJVnaiEEjAucKKiqFqnNC5YtK3mC2CIxaWbXY9DiB2K2326AiHD/Y
0bBbyJwTeBpPlDZKhmNDSSNnVW9OyOhUutFBD8PBY7ufHaniBHGmUx9Fe0Lx
++riok21nED7tfflnxehWP6eTNlwAydYNxYLc6SE4nYbxjcu/3HC3msK3Z/s
QrF4Y81/vqOcsFguTPlXfhlX5hJ/oji44IY9Q+HxgRC86LXL4JUNF9zSjS0U
8Q7ESg0WjuqHucDzQtXiCBGIbSWORj5w4AK2k1bkNf5AXNoa2H3VhQsYcByL
fPFF7KNU4WtxgQuC54J5qPQLeHpYO+/LXS5Q8kta2X87AA9YK0swjHEBCeL0
25f9MHee3l7fSS5onjl9tKrLDxsw7XMf/84FOlcCO3/l++HUIueK5r9c0Mcv
rCXm6IcP8mbZ3Gbjhvimwc8XWs/hd42bbsqqcsO32J+m/E98ca2+8JqRDzcY
7B1t5E7wxsjEvS3jPDfYheTTNvt540Gr2tSVi9ywkT30ykFvvORxdmtpGDcw
duncb6Z4Y+30ttNyidzApZuvFrb3LM5kCu9kLOcGxazubRqBXvhq29/cNyvc
UPHWuTRVwx0L9e73pzLywPu18vWBFTecMZ6515+VB0wXGMUvtLnhqlU0qM7H
A71ePFlFbm74r2a+8H0pHriqdXG/xNPT2CnR+VLQHh5w3lrY727gio0duq23
R/LArl/7H55NcsIGiQ3v5mJ4wLqpt0DX3QlrtJWa5d/mAYbuk940wgmL6icQ
snd5oPOldHPQ9Cn8jYTUeAp4QPExmT3X6BSOam9hGu7kAZ512TOd7CfxJeaX
IWm9PHDUTkwmfsQR+xrkLtp84YHznK7td185Yvvca79aJnhgzb7r301vR7w5
fO/n5/94QO8po8PQlxP4vx2vi69L8cLRr3FBMdHH8VvfZ5v3yPPCxWOUbzP7
juOKJ3cfryjzwhae66f7WI7jDHLgfR9tXhA5IDBmEHoM+/7ZdsPeeGN/d0fd
phAHTMorOqHpwQvWvlu5U2/Z48PUbP6eF7wQHvHbiMZ1CCu3a+fDK17InLlR
uavPDi+G1Jo/reaF9suD8jdy7XDqyGBESDMvWCaestMxtcPduWIrcp95IXZn
4ERrtC220ov95r3KC4TZA+QjdxDLTm269pmRD14+CKF/pdvg32nP5IzY+OD7
YuhqfrsNjltrOUbm54Opa4YjugE2+L8Glk+vpfmg1j8Siby3xhY2gbVcRnzA
uTD1LSXOCkuwcR73M+WDex0XpBncrfD38pSVLxZ8IKXbyfx8rxWOEi/TKz7I
B46SB94s0DFuHp3Jt3Plg81G6nWTpzA29nFOy47iA9V32ekMZggb3kLnDD/w
QYxu/o3zNyywn3vAG7ZuPjgl5FTFYmqBn5qkc/73mQ9ubaetSLFbYJH17w+O
j/OBheXUoYVr+/GPs9fbQ+kb8WXrUZab5vgufqNQv4kfXjZFq9YVm+L36l+9
o2X5YYdPNZF0wRSzcfFUWSvxgz3/E+5xwhT71h22GtfiB285Ynb2v33YfOv8
JVYjfng3ffl0/rwJXiRt7t3nzg+iyql+o7bGWOO3lZzAWX4gfVvayqhgjJ06
Lp7pPccPmTyafDf/GOH/IppY3EL4oWjfg+xvt41wzsLJLVFx/DDzLiAvpXMv
Pth7J6r9xUa+ioxnEu57cF/H1fRcRgF48vjRgZQqAmeL7khhZBGAf5xFSSd8
CXzm+FzsETYB0HUwzG9XJjDT7xNXeLgF4GSnrVxkiiHeTDJ08iYJQJR2Ytrp
4F348pFFle1KAnAhYr2u8uQObJ5VKHtbRQD2n5DWFJfdgUk/XMSn1Tb2k2/2
cI0a4NyQTzz3tARgvOWUScIpA/wxo2RmXV8AiLdMf5S99LHCpGdZk4UAfK7O
p/jc0cOzmvIF0jQBED8vOEc46uHKC/05F7EAnJvYdz9GRQ9bcpmnqtkKQI1z
v83dV9vwBXWloNjjAqDDtKbg+1UXt50bATtfAbDofeqqStPBPgy27RMpAqD1
SWvJwm8LfsrmYEtO28g3N5vWZbEFj/I4De+7JwAKou8OFylswVZivn9zMwSA
RN6a4tirhbW1b0l4PBGALf1j5Du7tfDcqUbPmUoBYBwId8kw1sCq7h0LUq8F
YBf9N/0ugwY+6d0ViqoFgE22eUmtSh1/DB5NLK7fqLf2spBFVx2XJK1VnWsX
gOzmv60X1Ddj36ZtvItfBMCsvmiX73ZV/LRjV4rysAB4ddd+VV9RwaOdRjKH
RwVAW2Xe3rNGBVsNW+lWTghAgYBInJe5Ctb+d8YheEYAxLw/xjo5KeM51cf5
DIyCsO62+7NJoSL2vUW25JQXhNGsjgfmaXL4y5NpDTdFQchtG2vKPS2HTRte
87coC0Ig89GuED05LLly6kOkuiCUO7f4RHbL4ja3IhsOPUGYnawTY6bKYnlj
M3t2c0FYo851FpZJ49gTEjtdLQTh6M4nvczR0ngpaEaiyVJwY163BapPSOP3
JUmD16wFYZ6v7JwrrzQOkR51ZHMQhBOtLO0d3ZK4eznwNKu3IKjJzQm+8pXA
u8mWZs6+gmA++8bEX0UCP9OWUW3wEwT39T9Hx4fFcZhb0/fwi4Igfae6+SMW
x5o9wmdZrgqCfGNnavsOKo4seXaeOVkQBJJ/1g5qULCB22AYY5UgGP2wvB5w
nYSF9zDOb3+zcT5iz7Y9B0n4B1Xe1btGEOQC/K9ckSPh++1u+4feCsL5R3/n
DtcKYwateeHXHYJwP0phyJZJGDcucD+6MCQIisGZW5+lCuIH/2mQi0Y26slX
BB7wEsQXcvGNyTFBmNHiOmKzRxCrHEnxsv0mCKI1iidjfwrgmNey23R+C8Kv
T8VXMk0FsFW4ftMMkxC8OevNwSLDh9UcjuorsQqBRft2Qc1uXsyy7XLeMXYh
6F5rGOOK4cVlk29jO7iFgHLKs/bdPx5M2Y8O5ZGEwJPvAL/DF248KOg65aIo
BFJ7uLP313NijweJ3INmQkDnO3WjhYEN/7XqR1wWQhB+7PmDU62sOJhNNnmb
pRCY85R0hSSy4hivQulYKyFgDqYoa6iy4mc7WnXBXggMpWY+Hrdnwb961o9n
egqBi5xEjFgXE/aPNnn07owQOFpbtus8YsJrhjenl7yFYJ+FulO1PxPmz6Ge
tz4vBCeavUolxZmwlp9uFMslIXhmcmt5+jQj9hXwKHWJFQIu43fvp8gMeKm+
+F/8bSHwQqz2wkPrKCxg0bA6QQjiZ4/ak2LXUcJgRAs5dUNP6F97699rqPRZ
xmBzhhDoJ5fYJL9ZRQum3RxqJULwXUTXpz5wGV28stthpksIVsRseFjP0pGO
uc0/8x4huHN5rtxKg45mhVyTcvqEoGFHLef+XwvIJTumw2FQCOJuedB1vBeQ
TVPPrvZJIVBdOK5fEzSPNHjPSD5ZEoLj7J8rrIr+oOlPoZUsq0LwQpP9Z9TF
P+hReoLtiXUhGOjy/Gyz9w+S0Hp5i8wiDOefJsql9s4hTmuW9QheYYi7psFQ
xjmHxlPThk5KC8Oejyk7yRGzKMMxP+iNrDB8Lc0ta7CdRfaqNWSqgjAckHc7
O6s8iz6++kr7oCIMUuuTpz3uz6DqQa0aYqswKNpc3/yK+IXS5JsyJEyEgeXQ
qIN+4XdEK/rj2O0hDAL45oKn6iS6sM02lvOMMOyqOF8+9GMCZVRVVO30FgZt
wTHFmcIJNNccQs7yE4a+Nk+FQb0JlDzC3nE2RBgC9LunOy2/okEhie2cscKg
qjH0eCxlDLHfueS887YwbCLJX/U/NYa0pEbizyYIQzGHcG+s5hgKU8v5+SlF
GBZEfrxDLaNI0UgrKzNDGLIjD5V9YxpFZ84b8e0sEYYK47654zeHUcpyzo6z
pcJg9Hn/w8YTw6jmCqdb5gthCJ4STMzQGUZCt97Vc7wShqp8jWLrV0PoRc6h
i5/qheGXdnH3hNsgWuvxHD/zSRhqHB48//WrH900SKp8uCgMnR9ynjZF9WzM
q96QZXmj/zOXdpGNe5CJz1ydy6ow+I2c/LWZoQetPaa1qTGRIPjP3X2ZF7rR
GRGugTJuEvD7GOAg30/IcvbSaoskCbjsxTPUIjvR0+j8K5tlSMAmSXH4caAT
sSkNsMbKkUBcIJTVhtSJ3jjo89kokyAvcZ0ukPURabb9kRzcQoJtt+9eEWj+
gARyTsOcEQnc7zltSHqPPHenvLXZR4J7QRbHZFb+Q80DDablZiRgFv4uznDv
PxQqLIeDLUmAFabYVgbfod+hXxzZDpFAxvb9kzSfDvTR3uoq1YME5meoT/42
tiINeih7iBcJpDfR5H6eb0VR8YXRQ2dJsCPZOOKDQiva08KTmO1Hgt+M6zXW
kS2oZFtTtsYlEtA37/xEt2tGCYI7G/fcJkHrsYn/Hko1oqPulf3BCST4aeJD
zh5uQIr123+/SCIB7Ywei3VmA6r005VQSyPB8MmgqkKlBjTco+ErnEWCt/od
ijoGb5FGuozkeCkJdk8nfJwLrkOLCw+2SpaTIN7BzOrvvjpUR5M0O/SSBE/6
nklGCtehg4zifu2vScD77GLiiWe1KNiJ1FraSIKOxdrIvPEa1KrK7h/RS4JU
7tdXugbeoMSrEdHVn0nwgiXapPHqG3RsgPnhvwESOD8YeFqo9gb9vsnQ7jVC
gqMiEWzHL71GlN//ZGynSTCe4+Y8pVGFXMp/dCiukCCWZSeKqXyJtAQ8xk6s
keDY6Paj78++REunpxbTGESApHyu+KvCS3STOiHHzyoCF+WGfIMSK1BpyNBF
Oq8IyBv/ViYHlSMmo48KzVIiwK+gNE54lqGgAD8+uowI/OeHT33SKEN/n4rS
FeRFwItMKSfNlaJJQfvmq8oiwHs/s+tGYClqHxpzJ7aIwMzUk9xNCc9RUtB8
4Ys9IqB42aInYKQY8RWmpH41EgHvUxfyhvOLUeSo/hXSPhFARVnyfYHFKNDs
kpXvfhF4+Rw4zokWo2Nk9nl1GxFIff3yooxNEVJ+TjF45CwCN9v+phx6n48e
TlTKdrmKQP9V7feNF/MRlerAzewuAh25zhVK8vmI98rDgRNnRIBtzsKlPOgZ
mrNUvSwRIAJ9M5LGzbp56NX0jrcJkSKw2hlqmNSZi3QkB5/VRYmA4UHnt5zR
uagAhyb9jhEBnhYx7v17c1FGxVsX2m0RmM07o6X24jEKv3aAkztNBLR3eror
PspBlrLHLcPyREAtW+OrYU42WnLvuDmcLwLxbGka7k7ZKOf5jg7Doo1+Mhf2
nZDLRutGFIvlUhEwlmaPzsrKQkWuH8z83ogAq7Cpskl+JhLO32vs8kEElM+d
OMU/loFq5ovD33aKgIbW7Q/9zzKQp6H0W9luEdBLk/dFARno7X8re4Y+b/h7
eMFPlS8D+c+VwaFxEaAG5TX0XEtHvXrKO83pIuDmd0BJKOkuCg9NDsr9JwJX
aIPVv3fcRVotLK/YVkTAxok0PTmWhm4cGdGvZxCF0pFtw1x6acggJE1vJ5co
5Imf6fswlYru1/Fs1dgkCoLre76WXUpG5txBvjFSopAan254QzcZLVhPFU/L
iEJ4rtPsnp9JyPJrg9ZjRVGwlSBfOHY8CTFwXNaQ1hIF/t/aN78fSEQnD/xW
EdorCl7xh8/IWsWjYOvCpX3GovDlw/s8SWo8Sj7s1RayTxSGL8m+qBm9jVqd
pzyn9ovCpNOh97/O30bal0YKa2xEwfPf5Zs1WXGIsfCD7lkXUVB3VXbx0LuF
qGWxbI9Oi8KZIApvwOebSOfVgZ7P7qLgRmJ/nHLpJjrd1HLB5KwoGE+Zm3O3
xqD3Q7WvNl0QhXVze1NXr2iUIVCyu/2GKGyPQytOY5GoUtRbiClGFKzphTlH
kyNRl4TGmN4tUfjbmG29wzwScag8Dc+KF4WwfaamWaXXkffuzKbAu6JQ/ZBB
tzvhGiJ84w+o5IsCUbG9OutiODp0AUkeLxSFHG+lwyP64cj3Et9MYrEotM8o
Ow8tXUU5UVFxDC9E4U72dRLp8lXElxXW2fNmw7/gip9ycWFosNP38LX3otA5
2l4n2BmK1GZWQr9/FIVg4/HGpTuh6ALX9Vz0SRRMX9dnPXAMRUK779Kpn0Uh
cPDDFqWJy8ikoD6pcEwUfjokP27ZeQkVRpI+9i5s6JEMYoxRCUIrWen/dv0T
hadvnos1tQci82plmaxlUehWE7yl6xOIxud3ensxkCEwcf/W+68vIsopZz4m
LjKsBrGkaThdQKG7XpirbSKDWLUPbfvX86jjEPjGSZHh3fLesL93ziOqX+ud
eRkyTKrfasmjnUelTwe/VSuSwYzn8Pzaaz/0jcx+3UaLDJrRzGEjj84hPGdX
H7J34zyJvp0lwwel845OjxqTodTXO5LrlA/6oewpZGpKhgMZ97K/KPqga8dD
HYUOkEE+3HtsqMgbVbbnrufYkuHnnQN7xO+dRbKP/+1470aGO6r3UkYOeiLJ
+4+3qXqSgVG+Qpl53gOJJxzcEn6GDF8PnD/ikuSBSJeLFbefI4PDUdLVkT53
xGbnJpgRTAY3oHbv9HFD02x9E2djyYCvc0oZdrugiZVrIy23yWAfeQoXXndB
Y3M6A3KJZNh57aKgkoELGhiM+9CTSoZzeygrEpnO6N0L0yoikwxpp/4wNYc4
oRKXitv8ZWTQMlSIcHU8iQqOusS4lZPhajX/aLPMSZRnRbpe/5IM+f96jBjG
HFG2oXdwwBsyRH+o2Dnh6oiSRZVdh5rIIFgwUWYUdAIFNqbsLPy8oW/73D6V
GAfkX2Wsx/mFDBNpnvF7FBzQuZI/W04NbfS3/6VZRfVR5JlOUyKPb/h1GjY/
XrRHx/zZhS7/JAP5eZqAWOARtFcxYNKSgQJZzZaSz8rtUEGf37lQJgrMpvi/
2eRuhyg3fdeLWShwT72f7domO/TjjxdZhJMCqqbTpRrXbVFirdO+fkEKNKMU
n1jng2jiqNVjVzkKyFXZxMhYWCMkgLbeUaDAm4jFnDwea1RZf6C6VYkCemHe
bQzvrNAtVbMe9c0UKLM4cpzJ2grpLRLsf3Uo8GuBLVrKBaPIBHXXUBMKnA6R
KrrsQENzJmp/ik0p8Du9dk/DvCU6uqR8ecycAoaHpAoPxVoiLUf5FBMaBQYU
93UdajyA+jTEm3gOUSCO2U2XttcCqbZyKN1xo4Dt4TiBuvNmKDGE7XmrB2Xj
/t67TVTGDK1psRArXhSodmYPCe4wRZ0p67bHfSnwcPXbuo+KKQp2XrimEEQB
o9c/BR/9NEEdDOMTxTEUGDtapuWVbYTcW/JbhGIp4Mpmf/H+YSPEER/w7Nxt
Coiwu7R94jdCe+S4fXWTKVDOf9sHXd6LKoy1VyseUMD/7KU7vO57UGZUqHBN
CQXuIN1rrR6ACGvzBekyCtyOcsz5rgloQJzUd6WcAjXBPD11UwQi5z9O31tF
gbt8Ed8vMREo5r93Kk0NFLDPO6Y8Y7IL+ZM2wbteCkzUplnxkA2Q8JcJWc1+
CnwtO73XvlwfFT0qYo37QoH+2sltDIf10fdtRm14lALFTQpZ+hnb0YnDHraf
vlOg4YzhsR+79JB5+kvPgTUKZDAF+8eV6KBJl6u0XYxiMDiZsXeriw4K1zyg
nc4sBnmWqPQbVQdV1wzTj3OIwbPLjTeCr29FOmPsV8cExSCStMg+6qmNpJRt
70zLi4Hn1A72e85aSLXgLK+ckhhYu3NwNmzWQjo6N67Yq4jB6L9FfHRKE5lD
lVu7uhi0Horv8eLVRP6HZA0KtonB0xLu1Dcu6uhd5K/PPqZioHuHm1nkiCrq
4+OgPTUXA1/rgcQdaypoPFGmftRCDKYKf5xKy1JBSxk2edZ4I5/f7MPZ38pI
4WVlkO4RMRga76q/fU8JBU9dk/jnIQYFdxiNTigqoOtnM+K2nBGDFcb5jN0D
8ih+/iWLu7cYbHHSdJVOkEe5jD9/fPYTA9eaHO4WZnnUKWb9uipEDELjCti9
ZmWRqrnUsdBYMXgiz3PP+q800n2//WPFbTH4eE4hIrlCGoGtlcnvhI34pHF3
Tog0sj0ZoXEyVQx6dar+yXNJo7DA72t7H4rByM9yfO+QJOp7Wv6A/fmGnm8W
zAcUxVEi9/yETpkY7OR8HMrQTEWWntoaJ8vFIDX2SMkfdyqqU8+vqnolBtdX
W6sjS8XQs6LMPp+3YiCl0WKwepCCLr+4KTzwSQxUaX9qXrwTQQbktiOcvWLA
qVd9JD5MBP0N4Mjc9lkMXm77eM1HTwSd1r+qdXtQDMLWBJTUs0nIqurCAZNJ
MZDVVurfdUMYKdSdul60uJHvQUES52VBNCz78N2XJTGY5l1fyNgtiNKuDopw
r4pBX6tvNxerIOIzPpztzEgFhh+q4vtvCaDFJstaKhd14z3OnXO24UdtHfrL
4eJUcPk6n9DGxYOuaQTsKdlEhfuvG3cMPOZGEFt6Y0iKCt5e/gO7TbhRKdKk
GMhTITIINJeucaH0Tnndmc1UuIRJNo/InMinj//sYUMqiNx9y2zsy4aO0cR4
XwAVJM/tjvwrzoYsGmTzhPZSgd+AeuxbIytSLNadbNtHhaSXJUFR0qxoINL+
uCGmAt+Zh2EGo8yodc1pNc2aClsfLUjeSmJG5X5n7tIPUsFIJuMpkzkzij9x
pafoCBXi+ApYDV8wIdPtj2lyTlSYq/ypd/MuI9pWUPTzsgsVWM0scIAdI5KT
r4weOE0F+qvCqpMkRrTG39GU5LWhx3+9TuM2AyqdnCM4Aqhg4vV23WvzOk06
xVDr5w0qpOXJbKImL9P4eE3fmcVQ4Z9D0LNu1WXachj2zLlFBbH9TEuqtUu0
7jNOuccTqFCS/mD31bl/tBiTKOmP96jwIdVpl5XrIi2wKuGNxgMqlK5UDKpx
LNJcte8fjX5IhUUuz13eT+m0PZJFqUY5VIhK19CQ/7NAW5z/JFBeSIVrWo8H
niTO0yY8hgqES6jAXDUxaAbztM6RbxbepVSYVf0SsPnnX1pBx3KkysuNeaTu
K8gx/0tzeiTDeK+OCp47ZR/OCP+hvbfx+h36iQqjvOa7eAZmaWqRjdJlPVRI
Hm5+qpY+S7v2SgpN9VEBlJq2qzjO0nbKfizAg1QQrIlXc+6coT2Z2eYpO0mF
wMdwzI7zFy0simGyfnFDj3UNe0T1NO3L68Oii0tU2BO9+2rf0Wna9t8lxptX
qfBj9bBo/PIU7Zedc3Yiozhs7yxfEN81RbNXaHV05hKHNb5+D973kzSdmoQB
NglxiHgZPuaz5Sst9s8P7h2S4nBi8F/N4Og4bVrRZMdZaXFQuPFf0emkcVrG
zcU7PfLiMJXKx/12dYzGa+9gl6suDvunBf3U+0dpE/OKH80IcZgRqGq52zBM
260Synhptzh8/ZReIXF9mHbvaJ9WyV5x2Ex2SL5iNkyzqo+OpZqKQziZMtP1
cIhWHTdr8R2JQ8sZV+OGzi+0VLXKppiT4iBzZWCo8upnWu+UXyKTszjcGZG5
s0T6TKPkajpecBWHrcl8+uuP+2h35B8tnfIUB8Nnq6sGnb20tE1x6jv8xaFp
c7/x6109tM/95ktFF8RhUC2c7DTQTaOmsTYpBonDuSdflNOCu2lpokEnhEI3
4m2qUndrP9Hu8rskTN3Y8MfxuNY+hy7aQIf0ieMx4iD/5ZDCG/YumkRM/+ZP
t8ThaMqJ74nPO2n3OHBjTcJG/32M4/v5N5hx57+U+xt6tfexm3d/oKX/ETxu
UiwOAc05kzt2/kcbLG5Xq3ouDiPBB7poFe9okt7XF7e8EAfVmMDLEdve0R78
WLm96ZU4DFn+K96q30HL+Dr59u9bcZANDDUqsW2jDWdl3nZvEoeHf178mBpt
pUmfdDg23CIOTxn+/mL0aaVlDH6kt70TB/Ynu56UxrfQHva8Vs3qFYf4n/M8
dt+baKNJF+iU/g1/uV/W10U00WRttr699UUcukqpEp9kmmiZ73MdAkc3/NAt
mf54rJGW2ZIQh3+IQ+E7C1rI97e00euWDk2/xMF9fCTTNf4tTdaEU3XXb3Ho
bbr+tMHgLS2r7lK98oI45Fto6TXE1tPGQ/Xj0hfFQTc3Qsl+Zz1Nnvh7lLQs
DuW3Ox8emK6jOa0WqEStisMNrklSyp06WvYrt4X19Q2ebmfVNq+j/Q/ugl78

     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.5263861754318657`*^9, 3.5263863859359426`*^9, 3.5263867864300213`*^9, {
   3.526390619479054*^9, 3.5263907721917477`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"guess", "[", 
   RowBox[{
   "0.5000094043887147`", ",", "0.000016653715500122788`", ",", ".4993", ",", 
    
    RowBox[{"-", ".00124"}]}], "]"}], "~", "N", "~", "10"}]], "Input",
 CellChangeTimes->{{3.526390625561676*^9, 3.526390798484166*^9}}],

Cell[BoxData["0.5000000030566544`"], "Output",
 CellChangeTimes->{{3.526390651501041*^9, 3.5263906739535418`*^9}, {
  3.5263907165148573`*^9, 3.5263907993336563`*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"guess", "[", 
   RowBox[{"\[Epsilon]1_", ",", "q1_", ",", "\[Epsilon]2_", ",", "q2_"}], 
   "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Epsilon]2", " ", "q1"}], "-", 
    RowBox[{"\[Epsilon]1", " ", "q2"}]}], 
   RowBox[{"q1", "-", "q2"}]]}]], "Input",
 CellChangeTimes->{{3.5263905434621983`*^9, 3.526390612060287*^9}}]
},
CellGrouping->Manual,
WindowSize->{740, 867},
WindowMargins->{{52, Automatic}, {Automatic, 124}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 622, 19, 36, "Subsubsection"],
Cell[CellGroupData[{
Cell[1204, 43, 809, 24, 89, "Input"],
Cell[2016, 69, 156, 4, 53, "Output"]
}, Open  ]],
Cell[2187, 76, 98, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[2310, 81, 336, 10, 52, "Input"],
Cell[2649, 93, 262, 5, 27, "Output"]
}, Open  ]],
Cell[2926, 101, 95, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[3046, 106, 224, 6, 53, "Input"],
Cell[3273, 114, 121, 2, 30, "Output"]
}, Open  ]],
Cell[3409, 119, 133, 2, 26, "Text"],
Cell[3545, 123, 553, 17, 46, "Input"],
Cell[4101, 142, 210, 4, 26, "Text"],
Cell[4314, 148, 484, 14, 27, "Input"],
Cell[4801, 164, 640, 11, 71, "Text"],
Cell[CellGroupData[{
Cell[5466, 179, 2144, 54, 181, "Input"],
Cell[7613, 235, 330, 9, 20, "Print"],
Cell[7946, 246, 14910, 250, 227, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22893, 501, 281, 7, 27, "Input"],
Cell[23177, 510, 167, 2, 27, "Output"]
}, Open  ]],
Cell[23359, 515, 367, 10, 49, "Input"]
}
]
*)

(* End of internal cache information *)

