(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     32069,        843]
NotebookOptionsPosition[     30273,        777]
NotebookOutlinePosition[     30627,        793]
CellTagsIndexPosition[     30584,        790]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
tunneling example BD 3.6.4
\
\>", "Subsubsection",
 CellChangeTimes->{{3.52560559609723*^9, 3.525605663919767*^9}, 
   3.525605699384592*^9}],

Cell["\<\
define wavefunctions in the three regions of space, psia for x<0
psib 0<x<a
psic x>a\
\>", "Text",
 CellChangeTimes->{{3.525605682377988*^9, 3.52560570806229*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"psia", "[", "x_", "]"}], "=", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"\[ImaginaryI]", " ", "k", " ", "x"}], "]"}], "+", 
    RowBox[{"r", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", "x"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"psib", "[", "x_", "]"}], "=", 
   RowBox[{
    RowBox[{"AA", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"\[Kappa]", " ", "x"}], "]"}]}], "+", 
    RowBox[{"BB", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", " ", "\[Kappa]"}], " ", "x"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"psic", "[", "x_", "]"}], "=", 
   RowBox[{"t", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"\[ImaginaryI]", " ", "k", " ", "x"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5256044466539917`*^9, 3.525604551334179*^9}, {
  3.52560567231632*^9, 3.5256056761152554`*^9}}],

Cell["\<\
set up boundary conditions:  wavefunctions and their derivatives must be \
equal at the boundaries\
\>", "Text",
 CellChangeTimes->{{3.5256057185274353`*^9, 3.525605740908877*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"boundarycond", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"psia", "[", "0", "]"}], "\[Equal]", 
     RowBox[{"psib", "[", "0", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"psia", "'"}], "[", "0", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"psib", "'"}], "[", "0", "]"}]}], ",", 
    RowBox[{
     RowBox[{"psib", "[", "a", "]"}], "\[Equal]", 
     RowBox[{"psic", "[", "a", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"psib", "'"}], "[", "a", "]"}], "\[Equal]", 
     RowBox[{
      RowBox[{"psic", "'"}], "[", "a", "]"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.525604568035906*^9, 3.5256046111235657`*^9}, {
  3.52560465502064*^9, 3.525604706627696*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "+", "r"}], "\[Equal]", 
    RowBox[{"AA", "+", "BB"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\[ImaginaryI]", " ", "k"}], "-", 
     RowBox[{"\[ImaginaryI]", " ", "k", " ", "r"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"AA", " ", "\[Kappa]"}], "-", 
     RowBox[{"BB", " ", "\[Kappa]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"BB", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "a"}], " ", "\[Kappa]"}]]}], "+", 
     RowBox[{"AA", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"a", " ", "\[Kappa]"}]]}]}], "\[Equal]", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "a", " ", "k"}]], " ", "t"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "BB"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "a"}], " ", "\[Kappa]"}]], " ", "\[Kappa]"}], "+", 
     RowBox[{"AA", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"a", " ", "\[Kappa]"}]], " ", "\[Kappa]"}]}], "\[Equal]", 
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "a", " ", "k"}]], " ", "k", " ", 
     "t"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5256047247387753`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"boundarycond", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "t", ",", "AA", ",", "BB"}], "}"}]}], "]"}], "//", 
   "Flatten"}]}]], "Input",
 CellChangeTimes->{{3.525604727090625*^9, 3.525604749094968*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"r", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], "+", 
        SuperscriptBox["\[Kappa]", "2"]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Kappa]"}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", "k", " ", 
       "\[Kappa]"}], "+", 
      SuperscriptBox["\[Kappa]", "2"], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]}]]}], ",", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", "a", " ", "k"}], "+", 
         RowBox[{"a", " ", "\[Kappa]"}]}]], " ", "k", " ", "\[Kappa]"}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
        SuperscriptBox["k", "2"]}], "-", 
       RowBox[{"2", " ", "k", " ", "\[Kappa]"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", "k", " ", 
        "\[Kappa]"}], "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[Kappa]", "2"]}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
        SuperscriptBox["\[Kappa]", "2"]}]}]]}]}], ",", 
   RowBox[{"AA", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "k", " ", 
       RowBox[{"(", 
        RowBox[{"k", "-", 
         RowBox[{"\[ImaginaryI]", " ", "\[Kappa]"}]}], ")"}]}], 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Kappa]"}], "+", 
       RowBox[{"2", " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", "k", " ", 
        "\[Kappa]"}], "+", 
       SuperscriptBox["\[Kappa]", "2"], "-", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
        SuperscriptBox["\[Kappa]", "2"]}]}]]}]}], ",", 
   RowBox[{"BB", "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", "k", " ", 
      RowBox[{"(", 
       RowBox[{"k", "+", 
        RowBox[{"\[ImaginaryI]", " ", "\[Kappa]"}]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", "k", " ", "\[Kappa]"}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", "k", " ", 
       "\[Kappa]"}], "+", 
      SuperscriptBox["\[Kappa]", "2"], "-", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
       SuperscriptBox["\[Kappa]", "2"]}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.525604770737527*^9, 3.525605756187598*^9}]
}, Open  ]],

Cell["\<\
Thad\[CloseCurlyQuote]s complex conjugate function (assumes all variables are \
real)\
\>", "Text",
 CellChangeTimes->{{3.525605762725305*^9, 3.525605780092648*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"conj", "[", "a_", "]"}], ":=", 
  RowBox[{"a", "/.", 
   RowBox[{
    RowBox[{"Complex", "[", 
     RowBox[{"x_", ",", "y_"}], "]"}], "\[Rule]", 
    RowBox[{"Complex", "[", 
     RowBox[{"x", ",", 
      RowBox[{"-", "y"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.525604821146881*^9, 3.5256048573005877`*^9}}],

Cell["\<\
t/.sol means:  replace t by the value given in sol\
\>", "Text",
 CellChangeTimes->{{3.525605834771296*^9, 3.525605854162403*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TT", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"t", "/.", "sol"}], ")"}], " ", 
    RowBox[{"conj", "[", 
     RowBox[{"t", "/.", "sol"}], "]"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5256048662430563`*^9, 3.5256048915067797`*^9}, {
  3.5256058685896053`*^9, 3.5256058687325478`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2", " ", "a", " ", "\[Kappa]"}]], " ", 
   SuperscriptBox["k", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], ")"}], "2"], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", "a", " ", "\[Kappa]"}]]}], ")"}], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Kappa]", "4"]}]}]]], "Output",
 CellChangeTimes->{{3.525604876413512*^9, 3.525604893014298*^9}, 
   3.525605815118948*^9, {3.5256058639322357`*^9, 3.525605869928295*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RR", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "/.", "sol"}], ")"}], " ", 
    RowBox[{"conj", "[", 
     RowBox[{"r", "/.", "sol"}], "]"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5256058731828327`*^9, 3.525605886245655*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], ")"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      SuperscriptBox["\[Kappa]", "2"]}], ")"}], "2"]}], 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], ")"}], "2"], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"4", " ", "a", " ", "\[Kappa]"}]]}], ")"}], " ", 
    SuperscriptBox["k", "2"], " ", 
    SuperscriptBox["\[Kappa]", "2"]}], "+", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", "a", " ", "\[Kappa]"}]]}], ")"}], "2"], " ", 
    SuperscriptBox["\[Kappa]", "4"]}]}]]], "Output",
 CellChangeTimes->{3.525605887359727*^9}]
}, Open  ]],

Cell["\<\
check conservation of particles\
\>", "Text",
 CellChangeTimes->{{3.525605918817906*^9, 3.525605930191551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"RR", "+", "TT"}], "]"}], "\[Equal]", "1"}]], "Input",
 CellChangeTimes->{{3.525605892675558*^9, 3.5256059101062117`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.525605898969161*^9, 3.525605911206978*^9}}]
}, Open  ]],

Cell[" or", "Text",
 CellChangeTimes->{{3.525605995899683*^9, 3.525605996187757*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RR", "+", "TT"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.525605997964801*^9, 3.525606002805108*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.525606003672716*^9}]
}, Open  ]],

Cell["\<\
find behavior in limit of a\[Kappa]>>1\
\>", "Text",
 CellChangeTimes->{{3.5256060945236073`*^9, 3.525606106452091*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TT", "/.", 
  RowBox[{
   RowBox[{"Exp", "[", " ", 
    RowBox[{"q_", " ", "a", " ", "\[Kappa]"}], "]"}], "\[Rule]", 
   RowBox[{"1", "/", 
    SuperscriptBox["b", "q"]}]}]}]], "Input",
 CellChangeTimes->{{3.5256060517296867`*^9, 3.525606084654948*^9}, {
  3.525606128846861*^9, 3.5256061325933228`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", 
   SuperscriptBox["k", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], 
  RowBox[{
   SuperscriptBox["b", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["1", 
          SuperscriptBox["b", "2"]]}], ")"}], "2"], " ", 
      SuperscriptBox["k", "4"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox["1", 
         SuperscriptBox["b", "4"]], "+", 
        FractionBox["6", 
         SuperscriptBox["b", "2"]]}], ")"}], " ", 
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox["\[Kappa]", "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox["1", 
          SuperscriptBox["b", "2"]]}], ")"}], "2"], " ", 
      SuperscriptBox["\[Kappa]", "4"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.525606120851503*^9, 3.525606152286701*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "0", ",", "2"}], "}"}]}], "]"}], "//", 
  "Normal"}]], "Input",
 CellChangeTimes->{{3.5256061372428083`*^9, 3.525606155101201*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", 
   SuperscriptBox["b", "2"], " ", 
   SuperscriptBox["k", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["\[Kappa]", "2"]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{{3.525606148571115*^9, 3.5256061563335943`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"b", "\[Rule]", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "a"}], " ", "\[Kappa]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.525606166035799*^9, 3.525606175090242*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{"16", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2"}], " ", "a", " ", "\[Kappa]"}]], " ", 
   SuperscriptBox["k", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["k", "2"], "+", 
     SuperscriptBox["\[Kappa]", "2"]}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.525606176459478*^9}]
}, Open  ]],

Cell["\<\
Note, typographical error in book for Eq 3.51\
\>", "Text",
 CellChangeTimes->{{3.525606193825809*^9, 3.525606224142323*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"TT", "//.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k", "\[Rule]", "\[Kappa]"}], ",", 
      RowBox[{"\[Kappa]", "\[Rule]", "1"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5256062556494617`*^9, 3.5256062976097393`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlXc8F94Xxu2s7Oz9kZ0i33b3HEQySkIlZRZSEllFKaKMzJDKKCRKkpFS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.5256062716879683`*^9, 3.5256062984580517`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 656},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 151, 5, 37, "Subsubsection"],
Cell[733, 29, 173, 5, 56, "Text"],
Cell[909, 36, 1030, 32, 73, "Input"],
Cell[1942, 70, 190, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[2157, 78, 731, 21, 43, "Input"],
Cell[2891, 101, 1355, 39, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4283, 145, 295, 8, 27, "Input"],
Cell[4581, 155, 4219, 109, 176, "Output"]
}, Open  ]],
Cell[8815, 267, 175, 4, 26, "Text"],
Cell[8993, 273, 352, 10, 27, "Input"],
Cell[9348, 285, 140, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[9513, 292, 344, 9, 27, "Input"],
Cell[9860, 303, 1259, 35, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11156, 343, 289, 8, 27, "Input"],
Cell[11448, 353, 1326, 41, 59, "Output"]
}, Open  ]],
Cell[12789, 397, 121, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[12935, 404, 185, 4, 27, "Input"],
Cell[13123, 410, 97, 1, 27, "Output"]
}, Open  ]],
Cell[13235, 414, 85, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[13345, 419, 148, 3, 27, "Input"],
Cell[13496, 424, 70, 1, 27, "Output"]
}, Open  ]],
Cell[13581, 428, 130, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[13736, 435, 328, 8, 33, "Input"],
Cell[14067, 445, 1057, 34, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15161, 484, 244, 7, 27, "Input"],
Cell[15408, 493, 376, 11, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15821, 509, 229, 6, 27, "Input"],
Cell[16053, 517, 427, 13, 56, "Output"]
}, Open  ]],
Cell[16495, 533, 135, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[16655, 540, 418, 11, 27, "Input"],
Cell[17076, 553, 13169, 220, 240, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

